@@ -10,10 +10,14 @@
 
 #include <stdlib.h>
 #include <stdarg.h>
-#include "compiler.h"
+#include "tic.h"
 
-extern char *string_table;
-extern short term_names;
+static const char *sourcename;
+
+void set_source(const char *name)
+{
+    sourcename = name;
+}
 
 void warning(const char *fmt, ...)
 {
@@ -21,7 +25,7 @@ void warning(const char *fmt, ...)
 
     va_start(argp,fmt);
     fprintf (stderr, "compile: Warning: near line %d: ", curr_line);
-    fprintf (stderr, "terminal '%s', ", string_table+term_names);
+    fprintf (stderr, "terminal '%s', ", sourcename);
     vfprintf (stderr, fmt, argp);
     fprintf (stderr, "\n");
     va_end(argp);
@@ -34,7 +38,7 @@ void err_abort(const char *fmt, ...)
 
     va_start(argp,fmt);
     fprintf (stderr, "compile: Line %d: ", curr_line);
-    fprintf (stderr, "terminal '%s', ", string_table+term_names);
+    fprintf (stderr, "terminal '%s', ", sourcename);
     vfprintf (stderr, fmt, argp);
     fprintf (stderr, "\n");
     va_end(argp);
@@ -48,7 +52,7 @@ void syserr_abort(const char *fmt, ...)
 
     va_start(argp,fmt);
     fprintf (stderr, "PROGRAM ERROR: Line %d: ", curr_line);
-    fprintf (stderr, "terminal '%s', ", string_table+term_names);
+    fprintf (stderr, "terminal '%s', ", sourcename);
     vfprintf (stderr, fmt, argp);
     fprintf (stderr, "\n");
     va_end(argp);
