@@ -311,7 +311,6 @@ WINDOW *win;
     char Buffer [80];
     chtype ch;
 
-    traceon();
     nl ();
     wclear (win);
     mvwaddstr(win, 1, 1, "You should now have a screen in the upper left corner, and this text should have wrapped");
@@ -374,7 +373,6 @@ WINDOW *win;
     wmove(win, 8, 1);
     wdeleteln(win);
     Continue(win);
-    traceoff();
 
     wmove (win, 5, 9);
     ch = winch (win);
